@@ -1,23 +1,21 @@
 
 
-# test_that("Test csu_asr: 1",{
-#   
-#   
-#   
-#   #input data
-#   data_test <-  read.csv(system.file("testdata","data_cervix.csv",package="Rcan"), sep=",")
-#   
-#   #output result
-#   output_test <- csu_asr(data_test,missing_age = 19,
-#                     group_by  = c("country", "country_label", "year", "sex","type"),
-#                     var_age_group =  c("country", "country_label","type"))
-#   
-# 
-#   expect_test <- readRDS(system.file("testdata","csu_asr_test1.rds",package="Rcan"))
-#   
-#   #test
-#   expect_equal(output_test, expect_test)
-# })
+test_that("Test csu_asr: 1",{
+
+  #input data
+  data_test <-  read.csv(system.file("testdata","data_cervix.csv",package="Rcan"), sep=",")
+
+  #output result
+  output_test <- csu_asr(data_test,missing_age = 19,
+                    group_by  = c("country", "country_label", "year", "sex","type"),
+                    var_age_group =  c("country", "country_label","type"))
+
+
+  expect_test <- readRDS(system.file("testdata","csu_asr_test1.rds",package="Rcan"))
+
+  #test
+  expect_equal(output_test, expect_test)
+})
 
 
 test_that("Test age specific: 1",{
@@ -88,7 +86,6 @@ test_that("Test eapc: 1",{
                    "asr", "year",
                    group_by=c("registry", "registry_label", "sex", "ethnic" ))
   
-  
   #expect result
   expect_test <- readRDS(system.file("testdata","csu_eapc_test1.rds",package="Rcan"))
   #test
